@@ -1,10 +1,15 @@
 #!/bin/echo Usage: . $0
 export WORKDIR=$(cd ..;pwd)
 
-export PYTHON=/usr/bin/python2.3
+# default to 2.3 if no value in $1 and $2
+export PY_MAJ=${1:-2}
+export PY_MIN=${2:-3}
+export PYCXX=${WORKDIR}/Import/pycxx_${PYCXXVER}
+
+export PYTHON=/usr/bin/python${PY_MAJ}.${PY_MIN}
 export MEINC_INSTALLER_DIR=${WORKDIR}/Import/MEINC_Installer
 export PYCHECKER_DIR=${WORKDIR}/Import/PyChecker
-for dir in ${WORKDIR}/../Extension/Source ${WORKDIR}/../pysvn/py23/Source
+for dir in ${WORKDIR}/../Extension/Source ${WORKDIR}/../pysvn/py${PY_MAJ}${PY_MIN}/Source
 do
 	if [ -e $dir ]
 	then
