@@ -12,6 +12,19 @@
 '''
 import wx
 
+menu_style_choices = [
+    'Normal -- /dir1/dir2/leafdir',
+    'Leaf in Parent -- leafdir in /dir1/dir2',
+    'Leaf only -- leafdir',
+    ]
+
+menu_style_names = [
+    'normal',
+    'leaf_in_parent',
+    'leaf_only',
+]
+
+
 class BookmarkManageDialog(wx.Dialog):
     def __init__( self, parent, bookmark_prefs ):
         wx.Dialog.__init__( self, parent, -1, "Manage Bookmarks" )
@@ -24,6 +37,23 @@ class BookmarkManageDialog(wx.Dialog):
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
         self.h_sizer1 = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer2 = wx.BoxSizer( wx.HORIZONTAL )
+        self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+        self.g_sizer.AddGrowableCol( 1 )
+
+        menu_style_index = 0
+        if self.bookmark_prefs.menu_style in menu_style_names:
+            menu_style_index = menu_style_names.index( self.bookmark_prefs.menu_style )
+
+        self.static_text1 = wx.StaticText( self, -1, "Menu Style: ", style=wx.ALIGN_RIGHT)
+        self.menu_style_ctrl = wx.Choice( self, -1, choices=menu_style_choices, size=(150,-1) )
+        self.menu_style_ctrl.SetStringSelection( menu_style_choices[menu_style_index] )
+        self.g_sizer.Add( self.static_text1, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.menu_style_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+
+        self.static_text2 = wx.StaticText( self, -1, "Leaf names to ignore: ", style=wx.ALIGN_RIGHT)
+        self.leaf_names_to_ignore_ctrl = wx.TextCtrl( self, -1, ','.join(self.bookmark_prefs.leaf_names_to_ignore), size=(300,-1) )
+        self.g_sizer.Add( self.static_text2, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.leaf_names_to_ignore_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
         self.bookmark_list = wx.ListCtrl( self, wx.NewId(), size=( 600, 200 ), style=wx.LC_REPORT )
         self.bookmark_list.InsertColumn( 0, "Bookmark" )
@@ -50,6 +80,7 @@ class BookmarkManageDialog(wx.Dialog):
         self.h_sizer2.Add( self.button_ok, 0, wx.EXPAND|wx.EAST, 15)
         self.h_sizer2.Add( self.button_cancel, 0, wx.EXPAND|wx.EAST, 2 )
 
+        self.v_sizer.Add( self.g_sizer, 0, wx.EXPAND|wx.ALL, 5 )
         self.v_sizer.Add( self.bookmark_list, 0, wx.EXPAND|wx.ALL, 5 )
         self.v_sizer.Add( self.h_sizer1, 0, wx.EXPAND|wx.ALL, 5 )
         self.v_sizer.Add( self.h_sizer2, 0, wx.EXPAND|wx.ALL, 5 )
@@ -86,6 +117,19 @@ class BookmarkManageDialog(wx.Dialog):
     def OnDeselectBookmark( self, event ):
         self.selection = None
         self.button_delete.Enable( False )
+    
+    def setPreferences( self ):
+        for bm_name in self.getDeletedBookmarkList():
+            self.bookmark_prefs.delBookmark( bm_name )
+
+        self.bookmark_prefs.leaf_names_to_ignore = self.getLeafNamesToIgnore()
+        self.bookmark_prefs.menu_style = self.getMenuStyle()
 
     def getDeletedBookmarkList( self ):
         return self.bookmark_deleted_list
+
+    def getMenuStyle( self ):
+        return menu_style_names[ self.menu_style_ctrl.GetSelection() ]
+
+    def getLeafNamesToIgnore( self ):
+        return [s.strip() for s in self.leaf_names_to_ignore_ctrl.GetValue().split(',')]
