@@ -103,6 +103,9 @@ class WbFrame(wx.Frame):
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Checkin, 'Checkin...', 'Checkin...' )
         self.menu_actions.AppendSeparator()
+        self.menu_actions.Append( wb_ids.id_SP_Lock, 'Lock...', 'Lock...' )
+        self.menu_actions.Append( wb_ids.id_SP_Unlock, 'Unlock...', 'Unlock...' )
+        self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Mkdir, 'Make directory...', 'Make directory...' )
         self.menu_actions.Append( wb_ids.id_SP_Add, 'Add', 'Add' )
         self.menu_actions.Append( wb_ids.id_SP_Rename, 'Rename', 'Rename' )
@@ -110,7 +113,7 @@ class WbFrame(wx.Frame):
         self.menu_actions.Append( wb_ids.id_SP_Delete, 'Delete', 'Delete' )
         self.menu_actions.Append( wb_ids.id_SP_Revert, 'Revert', 'Revert' )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Cleanup, 'Clear Locks', 'Clear Locks' )
+        self.menu_actions.Append( wb_ids.id_SP_Cleanup, 'Clean up', 'Clean up working copy' )
 
         self.menu_view = wx.Menu()
         self.menu_view.AppendCheckItem( wb_ids.id_View_ControlledFiles, "Show &Controlled files", "Show Controlled files" )
@@ -129,13 +132,7 @@ class WbFrame(wx.Frame):
         self.menu_bookmarks.Append(  wb_ids.id_Bookmark_Manage, 'Manage...', 'Manage Bookmarks' )
         self.menu_bookmarks.AppendSeparator()
 
-        bm_prefs = self.app.prefs.getBookmarks()
-        for bm_name in bm_prefs.getBookmarkNames():
-            if bm_name == 'last position':
-                continue
-
-            pi = bm_prefs.getBookmark( bm_name )
-            self.__addBookmarkMenuItem( pi )
+        self.__bookmarkMenuReorder()
 
         self.menu_help = wx.Menu()
         self.menu_help.Append( wx.ID_ABOUT, "&About...", "About the application" )
@@ -251,6 +248,8 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_History, self.app.eventWrapper( self.OnUpdateUiSpHistory ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Info, self.app.eventWrapper( self.OnSpInfo ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Info, self.app.eventWrapper( self.OnUpdateUiSpInfo ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_Lock, self.app.eventWrapper( self.OnSpLock ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Lock, self.app.eventWrapper( self.OnUpdateUiSpLock ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Mkdir, self.app.eventWrapper( self.OnSpMkdir ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Mkdir, self.app.eventWrapper( self.OnUpdateUiSpMkdir ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Properties, self.app.eventWrapper( self.OnSpProperties ) )
@@ -261,6 +260,8 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Resolved, self.app.eventWrapper( self.OnUpdateUiSpResolved ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Revert, self.app.eventWrapper( self.OnSpRevert ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Revert, self.app.eventWrapper( self.OnUpdateUiSpRevert ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_Unlock, self.app.eventWrapper( self.OnSpUnlock ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Unlock, self.app.eventWrapper( self.OnUpdateUiSpUnlock ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnSpUpdate ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnUpdateUiSpUpdate ) )
 
@@ -457,14 +458,34 @@ class WbFrame(wx.Frame):
         self.tree_panel.selectTreeNode( filename )
 
     #------------------------------------------------------------------------
-    def __addBookmarkMenuItem( self, pi ):
-            bm_id = wx.NewId()
+    def __addBookmarkMenuItem( self, menu_name, pi ):
+        bm_id = wx.NewId()
 
-            self.bookmark_id_map[ bm_id ] = pi
+        self.bookmark_id_map[ bm_id ] = pi
 
-            self.menu_bookmarks.Append( bm_id, pi.wc_path, pi.wc_path )
-            try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
-            wx.EVT_MENU( self, bm_id, try_wrapper( self.OnBookmarkGoto ) )
+        self.menu_bookmarks.Append( bm_id, menu_name, pi.wc_path )
+        try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
+        wx.EVT_MENU( self, bm_id, try_wrapper( self.OnBookmarkGoto ) )
+
+    def __bookmarkMenuReorder( self ):
+        for menu_id in self.bookmark_id_map.keys():
+            self.menu_bookmarks.Delete( menu_id )
+
+        self.bookmark_id_map = {}
+
+        bm_prefs = self.app.prefs.getBookmarks()
+        bookmark_list = []
+        for bm_name in bm_prefs.getBookmarkNames():
+            if bm_name == 'last position':
+                continue
+
+            pi = bm_prefs.getBookmark( bm_name )
+            bookmark_list.append( (bm_prefs.getMenuName( pi.wc_path ), pi) )
+
+        bookmark_list.sort( lambda a, b: cmp( a[0].lower(), b[0].lower() ) )
+
+        for menu_name, pi in bookmark_list:
+            self.__addBookmarkMenuItem( menu_name, pi )
 
     def OnBookmarkAdd( self, event ):
         pi = self.tree_panel.getSelectionProjectInfo()
@@ -476,7 +497,8 @@ class WbFrame(wx.Frame):
             print 'Adding bookmark to %s' % pi.wc_path
             bm_prefs.addBookmark( pi.wc_path, pi )
 
-            self.__addBookmarkMenuItem( pi )
+            self.__addBookmarkMenuItem( bm_prefs.getMenuName( pi.wc_path ), pi )
+            self.__bookmarkMenuReorder()
             self.app.savePreferences()
 
     def OnBookmarkManage( self, event ):
@@ -486,14 +508,9 @@ class WbFrame(wx.Frame):
         if rc != wx.ID_OK:
             return
 
-        deleted_bookmarks = dialog.getDeletedBookmarkList()
-        for bm_name in deleted_bookmarks:
-            item = self.menu_bookmarks.FindItem( bm_name )
-            self.menu_bookmarks.Delete( item )
-
-            bookmarks.delBookmark( bm_name )
-
+        dialog.setPreferences()
         self.app.savePreferences()
+        self.__bookmarkMenuReorder()
 
     def OnBookmarkGoto( self, event ):
         self.tree_panel.gotoBookmark( self.bookmark_id_map[event.GetId()].wc_path )
@@ -636,6 +653,13 @@ class WbFrame(wx.Frame):
         self.getUpdateUiState()
         event.Enable( self.ui_state_focus.versioned )
 
+    def OnSpLock( self, event ):
+        return self.Sp_Dispatch( 'OnSpLock' )
+
+    def OnUpdateUiSpLock( self, event ):
+        self.getUpdateUiState()
+        event.Enable( self.ui_state_tree.file_exists )
+
     def OnSpMkdir( self, event ):
         return self.Sp_Dispatch( 'OnSpMkdir' )
 
@@ -671,6 +695,13 @@ class WbFrame(wx.Frame):
         self.getUpdateUiState()
         event.Enable( self.ui_state_focus.need_checkin or not self.ui_state_focus.file_exists )
 
+    def OnSpUnlock( self, event ):
+        return self.Sp_Dispatch( 'OnSpUnlock' )
+
+    def OnUpdateUiSpUnlock( self, event ):
+        self.getUpdateUiState()
+        event.Enable( self.ui_state_tree.file_exists )
+
     def OnSpUpdate( self, event ):
         return self.Sp_Dispatch( 'OnSpUpdate' )
 
@@ -728,13 +759,13 @@ class LogCtrlPanel(wx.Panel):
         self.text_ctrl = StyledLogCtrl( self.app, self )
 
         # Redirect the console IO to this panel
-        if not self.app._debug_noredirect:
+        if self.app.isStdIoRedirect():
             sys.stdin = file( wb_platform_specific.getNullDevice(), 'r' )
             sys.stdout = self
             sys.stderr = self
 
         # Redirect log to the Log panel
-        if not self.app._debug_noredirect:
+        if self.app.isStdIoRedirect():
             log_handler = LogHandler( self.text_ctrl )
             self.app.log.addHandler( log_handler )
 
