@@ -45,16 +45,18 @@ id_SP_Checkin = wx.NewId()
 id_SP_Checkout = wx.NewId()
 id_SP_Cleanup = wx.NewId()
 id_SP_Delete = wx.NewId()
+id_SP_DiffMineNew = wx.NewId()
+id_SP_DiffOldMine = wx.NewId()
 id_SP_DiffOldNew = wx.NewId()
 id_SP_DiffWorkBase = wx.NewId()
 id_SP_DiffWorkHead = wx.NewId()
-id_SP_DiffMineNew = wx.NewId()
-id_SP_DiffOldMine = wx.NewId()
 id_SP_History = wx.NewId()
 id_SP_Info = wx.NewId()
-id_SP_Properties = wx.NewId()
+id_SP_Lock = wx.NewId()
 id_SP_Mkdir = wx.NewId()
+id_SP_Properties = wx.NewId()
 id_SP_Rename = wx.NewId()
-id_SP_Revert = wx.NewId()
 id_SP_Resolved = wx.NewId()
+id_SP_Revert = wx.NewId()
+id_SP_Unlock = wx.NewId()
 id_SP_Update = wx.NewId()
