@@ -422,6 +422,9 @@ class WbListPanel(wx.Panel):
     def OnSpInfo( self ):
         return self.Sp_Dispatch( 'Cmd_File_Info' )
 
+    def OnSpLock( self ):
+        return self.Sp_Dispatch( 'Cmd_File_Lock' )
+
     def OnSpProperties( self ):
         return self.Sp_Dispatch( 'Cmd_File_Properties' )
 
@@ -434,6 +437,9 @@ class WbListPanel(wx.Panel):
     def OnSpResolved( self ):
         return self.Sp_Dispatch( 'Cmd_File_Resolved' )
 
+    def OnSpUnlock( self ):
+        return self.Sp_Dispatch( 'Cmd_File_Unlock' )
+
     def OnSpUpdate( self ):
         return self.Sp_Dispatch( 'Cmd_File_Update' )
 
