@@ -28,9 +28,12 @@ def getPreferencesFilename():
 def getLogFilename():
     return os.path.join( getApplicationDir(), 'WorkBench.log' )
 
-def getLastMessageFilename():
+def getLastCheckinMessageFilename():
     return os.path.join( getApplicationDir(), 'log_message.txt' )
 
+def getLastLockMessageFilename():
+    return os.path.join( getApplicationDir(), 'lock_message.txt' )
+
 def setupPlatform():
     app_dir = getApplicationDir()
     if not os.path.exists( app_dir ):
