@@ -14,6 +14,7 @@ import wx
 import wb_exceptions
 import os
 import wb_subversion_list_handler
+import wb_shell_commands
 
 class PreferencesDialog( wx.Dialog ):
     def __init__( self, parent, app ):
@@ -39,9 +40,7 @@ class PreferencesDialog( wx.Dialog ):
 
         self.notebook = wx.Notebook( self, -1, size = (400, 200) )
 
-        self.notebook_sizer = wx.NotebookSizer( self.notebook )
-
-        self.v_sizer.Add( self.notebook_sizer, 0, wx.EXPAND|wx.ALL, 5 )
+        self.v_sizer.Add( self.notebook, 0, wx.EXPAND|wx.ALL, 5 )
 
         self.pages = []
         self.pages.append( EditorPage( self.notebook, self.app ) )
@@ -193,17 +192,42 @@ class ShellPage(PagePanel):
     def initControls( self ):
         p = self.app.prefs.getShell()
 
-        self.static_text1 = wx.StaticText( self, -1, "Init Command: ", style=wx.ALIGN_RIGHT)
-        self.text_ctrl_shell_init_command = wx.TextCtrl( self, -1, p.shell_init_command, wx.DefaultPosition, wx.Size(315, -1) )
+        self.static_text1 = wx.StaticText( self, -1, "Terminal Init Command: ", style=wx.ALIGN_RIGHT)
+        self.text_ctrl_shell_init_command = wx.TextCtrl( self, -1, p.shell_init_command, wx.DefaultPosition, wx.Size(300, -1) )
 
-        self.grid_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
+        self.grid_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.grid_sizer.AddGrowableCol( 1 )
 
-        self.grid_sizer.Add( self.static_text1, 1, wx.EXPAND|wx.NORTH, 3 )
+        terminal_program_list = wb_shell_commands.getTerminalProgramList()
+        if len(terminal_program_list) > 0:
+            self.static_text2 = wx.StaticText( self, -1, "Terminal Program: ", style=wx.ALIGN_RIGHT)
+            self.terminal_program_list_ctrl = wx.Choice( self, -1, choices=terminal_program_list, size=(150,-1) )
+            if p.shell_terminal in terminal_program_list:
+                self.terminal_program_list_ctrl.SetStringSelection( p.shell_terminal )
+            else:
+                self.terminal_program_list_ctrl.SetStringSelection( terminal_program_list[0] )
+            self.grid_sizer.Add( self.static_text2, 1, wx.EXPAND|wx.NORTH, 5 )
+            self.grid_sizer.Add( self.terminal_program_list_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
+        else:
+            self.terminal_program_list_ctrl = None
+
+        self.grid_sizer.Add( self.static_text1, 1, wx.EXPAND|wx.NORTH, 5 )
         self.grid_sizer.Add( self.text_ctrl_shell_init_command, 0, wx.EXPAND|wx.EAST, 5 )
-        self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
-        self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
-        self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
+
+        file_browser_program_list = wb_shell_commands.getFileBrowserProgramList()
+
+        if len(file_browser_program_list) > 0:
+            self.static_text3 = wx.StaticText( self, -1, "File Brower Program: ", style=wx.ALIGN_RIGHT)
+            self.file_browser_program_list_ctrl = wx.Choice( self, -1, choices=file_browser_program_list, size=(150,-1) )
+            if p.shell_file_browser in file_browser_program_list:
+                self.file_browser_program_list_ctrl.SetStringSelection( p.shell_file_browser )
+            else:
+                self.file_browser_program_list_ctrl.SetStringSelection( file_browser_program_list[0] )
+            self.grid_sizer.Add( self.static_text3, 1, wx.EXPAND|wx.NORTH, 5 )
+            self.grid_sizer.Add( self.file_browser_program_list_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
+        else:
+            self.file_browser_program_list_ctrl = None
+
         self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
 
         return self.grid_sizer
@@ -212,6 +236,10 @@ class ShellPage(PagePanel):
         p = self.app.prefs.getShell()
 
         p.shell_init_command = self.text_ctrl_shell_init_command.GetValue().encode('UTF-8')
+        if self.file_browser_program_list_ctrl is not None:
+            p.shell_file_browser = self.file_browser_program_list_ctrl.GetStringSelection().encode('UTF-8')
+        if self.terminal_program_list_ctrl is not None:
+            p.shell_terminal = self.terminal_program_list_ctrl.GetStringSelection().encode('UTF-8')
 
     def validate( self ):
         return True
