@@ -27,8 +27,6 @@ name_text_ctrl_id = wx.NewId()
 url_trunk_path_text_ctrl_id = wx.NewId()
 url_tags_path_text_ctrl_id = wx.NewId()
 url_tags_path_enable_ctrl_id = wx.NewId()
-url_branches_path_text_ctrl_id = wx.NewId()
-url_branches_path_enable_ctrl_id = wx.NewId()
 
 wizard_id = wx.NewId()
 
@@ -74,10 +72,6 @@ class ProjectDialog(wx.Dialog):
         self.url_tags_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
         self.url_tags_enable_ctrl = wx.CheckBox( self, url_tags_path_enable_ctrl_id, 'Enable' )
 
-        self.url_branches_label = wx.StaticText( self, -1, 'Subversion Branches URL:', style=wx.ALIGN_RIGHT )
-        self.url_branches_ctrl = wx.TextCtrl( self, url_branches_path_text_ctrl_id, '' )
-        self.url_branches_enable_ctrl = wx.CheckBox( self, url_branches_path_enable_ctrl_id, 'Enable' )
-
         self.g_sizer.Add( self.url_trunk_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.url_trunk_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
         self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
@@ -86,10 +80,6 @@ class ProjectDialog(wx.Dialog):
         self.g_sizer.Add( self.url_tags_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
         self.g_sizer.Add( self.url_tags_enable_ctrl, 0, wx.EXPAND )
 
-        self.g_sizer.Add( self.url_branches_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
-        self.g_sizer.Add( self.url_branches_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
-        self.g_sizer.Add( self.url_branches_enable_ctrl, 0, wx.EXPAND )
-
         self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
         self.button_ok.SetDefault()
         self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
@@ -116,9 +106,7 @@ class ProjectDialog(wx.Dialog):
         wx.EVT_TEXT( self, wc_path_text_ctrl_id, self.updateControls )
         wx.EVT_TEXT( self, url_trunk_path_text_ctrl_id, self.updateControls )
         wx.EVT_TEXT( self, url_tags_path_text_ctrl_id, self.updateControls )
-        wx.EVT_TEXT( self, url_branches_path_text_ctrl_id, self.updateControls )
         wx.EVT_CHECKBOX( self, url_tags_path_enable_ctrl_id, self.updateControls )
-        wx.EVT_CHECKBOX( self, url_branches_path_enable_ctrl_id, self.updateControls )
         self._update_controls_lock = False
 
     def updateControls( self, event=None ):
@@ -155,15 +143,6 @@ class ProjectDialog(wx.Dialog):
                 url_parts[ url_parts.index('trunk') ] = 'tags'
                 self.url_tags_ctrl.SetValue( '/'.join( url_parts ) )
 
-        if( self.url_branches_enable_ctrl.IsChecked()
-        and url is not None
-        and self.url_branches_ctrl.GetValue().strip() == ''):
-            url_parts = url.split('/')
-            if 'trunk' in url_parts:
-                url_parts[ url_parts.index('trunk') ] = 'branches'
-                self.url_branches_ctrl.SetValue( '/'.join( url_parts ) )
-
-
         self._update_controls_lock = False
 
 
@@ -196,12 +175,6 @@ class ProjectDialog(wx.Dialog):
                 style=wx.OK|wx.ICON_ERROR );
             return
 
-        url = self.url_branches_ctrl.GetValue().strip()
-        if url and not is_url( url ):
-            wx.MessageBox( '%s is not a valid Subversion branches URL' % url,
-                style=wx.OK|wx.ICON_ERROR );
-            return
-
         if self.wc_path_ctrl.GetValue().strip() == '':
             wx.MessageBox( 'Enter a Working copy path', style=wx.OK|wx.ICON_ERROR );
             return
@@ -233,8 +206,7 @@ class ProjectDialog(wx.Dialog):
         pi.init( self.name_ctrl.GetValue().strip(),
             wc_path=os.path.expanduser( self.wc_path_ctrl.GetValue().strip() ),
             url=self.url_trunk_ctrl.GetValue().strip(),
-            tags_url=self.url_tags_ctrl.GetValue().strip(),
-            branches_url=self.url_branches_ctrl.GetValue().strip() )
+            tags_url=self.url_tags_ctrl.GetValue().strip() )
 
         return pi
 
@@ -250,9 +222,7 @@ class UpdateProjectDialog(ProjectDialog):
         self.url_trunk_ctrl.SetValue( self.project_info.url )
         self.wc_path_ctrl.SetValue( self.project_info.wc_path )
         self.url_tags_ctrl.SetValue( self.project_info.tags_url )
-        self.url_branches_ctrl.SetValue( self.project_info.branches_url )
         self.url_tags_enable_ctrl.SetValue( self.project_info.tags_url != '' )
-        self.url_branches_enable_ctrl.SetValue( self.project_info.branches_url != '' )
 
         self.updateControls()
 
