@@ -7,12 +7,18 @@
 
  ====================================================================
 
-    wb_shell_unix_commands.py
+    wb_shell_macosx_commands.py
 
 '''
 import os
 import xml.sax.saxutils
 
+def getTerminalProgramList():
+    return ['Terminal']
+
+def getFileBrowserProgramList():
+    return ['Finder']
+
 def EditFile( app, project_info, filename ):
     p = app.prefs.getEditor()
 
