@@ -381,6 +381,9 @@ class SubversionListHandler(wb_list_panel.ListHandler):
                 ,('', wb_ids.id_SP_Info, 'Information...' )
                 ,('', wb_ids.id_SP_Properties, 'Properties...' )
                 ,('-', 0, 0 )
+                ,('', wb_ids.id_SP_Lock, 'Lock...' )
+                ,('', wb_ids.id_SP_Unlock, 'Unlock...' )
+                ,('-', 0, 0 )
                 ,('', wb_ids.id_SP_Update, 'Update' )
                 ,('-', 0, 0 )
                 ,('', wb_ids.id_SP_Checkin, 'Checkin...' )
@@ -391,7 +394,7 @@ class SubversionListHandler(wb_list_panel.ListHandler):
                 ,('', wb_ids.id_SP_Delete, 'Delete' )
                 ,('', wb_ids.id_SP_Revert, 'Revert' )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Cleanup, 'Clear locks' )
+                ,('', wb_ids.id_SP_Cleanup, 'Clean up' )
                 ]
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_template )
@@ -451,16 +454,14 @@ class SubversionListHandler(wb_list_panel.ListHandler):
     #------------------------------------------------------------
     def Cmd_File_Add( self, all_rows ):
         try:
-            for row in all_rows:
-                filename = self.getFilename( row )
+            for filename in [self.getFilename( row ) for row in all_rows]:
                 self.project_info.client_fg.add( filename )
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
         self.app.refreshFrame()
 
     def Cmd_File_Annotate( self, all_rows ):
-        for row in all_rows:
-            filename = self.getFilename( row )
+        for filename in [self.getFilename( row ) for row in all_rows]:
             self.app.setProgress( 'Annotating %(count)d', 0 )
 
             self.app.setAction( 'Annotate %s...' % filename )
@@ -487,7 +488,7 @@ class SubversionListHandler(wb_list_panel.ListHandler):
 
     def Cmd_File_Checkin( self, all_rows ):
         if len(all_rows) == 0:
-            wx.MessageBox( "There are no changes to checkin",
+            wx.MessageBox( "There are no changes to check in",
                 "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
             return
 
@@ -522,32 +523,32 @@ class SubversionListHandler(wb_list_panel.ListHandler):
 
     def Cmd_File_Cleanup( self, all_rows ):
         try:
-            for row in all_rows:
-                filename = self.getFilename( row )
+            for filename in [self.getFilename( row ) for row in all_rows]:
                 self.project_info.client_fg.cleanup( filename )
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
         self.app.refreshFrame()
 
     def Cmd_File_Delete( self, all_rows ):
-        if self.app.confirmAction( 'Delete', self.getStatusAndFilenames( all_rows ) ):
-            for row in all_rows:
-                if self.isControlled( row ):
-                    try:
-                        self.project_info.client_fg.remove( self.getFilename( row ) )
-                    except pysvn.ClientError, e:
-                        self.app.log_client_error( e )
-                else:
-                    try:
-                        os.remove( self.getFilename( row ) )
-                    except (OSError,IOError), e:
-                        self.app.log.error( str(e) )
+        if not self.app.confirmAction( 'Delete', self.getStatusAndFilenames( all_rows ) ):
+            return
 
-            self.app.refreshFrame()
+        for filename, controlled in [(self.getFilename( row ), self.isControlled( row )) for row in all_rows]:
+            if controlled:
+                try:
+                    self.project_info.client_fg.remove( filename )
+                except pysvn.ClientError, e:
+                    self.app.log_client_error( e )
+            else:
+                try:
+                    os.remove( filename )
+                except (OSError,IOError), e:
+                    self.app.log.error( str(e) )
+
+        self.app.refreshFrame()
 
     def Cmd_File_DiffWorkBase( self, all_rows ):
-        for row in all_rows:
-            filename = self.getFilename( row )
+        for filename in [self.getFilename( row ) for row in all_rows]:
             self.app.setAction( 'Diff BASE %s...' % filename )
             base_filename = os.path.join(
                 self.project_info.wc_path,
@@ -560,8 +561,7 @@ class SubversionListHandler(wb_list_panel.ListHandler):
         self.app.setAction( 'Ready' )
 
     def Cmd_File_DiffWorkHead( self, all_rows ):
-        for row in all_rows:
-            filename = self.getFilename( row )
+        for filename in [self.getFilename( row ) for row in all_rows]:
             url = self.getUrl( row )
 
             self.app.setAction( 'Diff HEAD %s...' % filename )
@@ -606,9 +606,8 @@ class SubversionListHandler(wb_list_panel.ListHandler):
             new_filename = self.getConflictNew( row )
             self.app.Diff( mine_filename, mine_filename, new_filename, new_filename )
 
-    def Cmd_File_History( self, rows ):
-        for row in rows:
-            filename = self.getFilename( row )
+    def Cmd_File_History( self, all_rows ):
+        for filename in [self.getFilename( row ) for row in all_rows]:
             self.app.setAction( 'History %s...' % filename )
 
             yield self.app.backgroundProcess
@@ -635,15 +634,6 @@ class SubversionListHandler(wb_list_panel.ListHandler):
                             '' ) )
 
 
-                branches_url = self.project_info.getBranchesUrl( info.url )
-                if branches_url:
-                    for ls_info in self.project_info.client_bg.ls( branches_url ):
-                        history_entries.append( (ls_info['created_rev'].number,
-                            ls_info['last_author'],
-                            ls_info['time'],
-                            'Branch ' + ls_info['name'].split('/')[-1],
-                            '' ) )
-
                 history_entries.sort()
 
                 ok = True
@@ -660,12 +650,13 @@ class SubversionListHandler(wb_list_panel.ListHandler):
 
         self.app.setAction( 'Ready' )
 
-    def Cmd_File_Info( self, rows ):
-        for row in rows:
-            filename = self.getFilename( row )
-
+    def Cmd_File_Info( self, all_rows ):
+        for filename in [self.getFilename( row ) for row in all_rows]:
             try:
-                entry = self.project_info.client_fg.info( filename )
+                if hasattr( self.project_info.client_fg, 'info2' ):
+                    entry = self.project_info.client_fg.info2( filename, recurse=False )
+                else:
+                    entry = self.project_info.client_fg.info( filename )
 
                 dialog = wb_subversion_info_dialog.InfoDialog( self.app,
                         self.list_panel.list_ctrl,
@@ -676,11 +667,39 @@ class SubversionListHandler(wb_list_panel.ListHandler):
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
 
-    def Cmd_File_Properties( self, rows ):
-        client_fg = self.project_info.client_fg
-        for row in rows:
-            filename = self.getFilename( row )
+    def Cmd_File_Lock( self, all_rows ):
+        all_filenames = [self.getFilename( row ) for row in all_rows]
+        comment, force = self.app.getLockMessage( 'Lock', self.getStatusAndFilenames( all_rows ) )
+        if not comment:
+            return
 
+        for filename in all_filenames:
+            self.app.setProgress( 'Locking %(count)d', 0 )
+
+            self.app.setAction( 'Locking %s...' % filename )
+
+            yield self.app.backgroundProcess
+
+            ok = False
+            try:
+                self.project_info.client_bg.lock( filename, comment=comment, force=force )
+                ok = True
+            except pysvn.ClientError, e:
+                self.app.log_client_error( e )
+
+            yield self.app.foregroundProcess
+
+            if not ok:
+                break
+
+        self.app.clearProgress()
+        self.app.setAction( 'Ready' )
+        self.app.refreshFrame()
+
+    def Cmd_File_Properties( self, all_rows ):
+        client_fg = self.project_info.client_fg
+
+        for filename in [self.getFilename( row ) for row in all_rows]:
             try:
                 prop_list = client_fg.proplist( filename,
                         revision=pysvn.Revision( pysvn.opt_revision_kind.working ) )
@@ -688,10 +707,16 @@ class SubversionListHandler(wb_list_panel.ListHandler):
                     prop_dict = {}
                 else:
                     _, prop_dict = prop_list[0]
-                dialog = wb_subversion_properties_dialog.PropertiesDialog( self.app,
-                        self.list_panel.list_ctrl,
-                        filename,
-                        prop_dict )
+                if os.path.isdir( filename ):
+                    dialog = wb_subversion_properties_dialog.DirPropertiesDialog( self.app,
+                            self.list_panel.list_ctrl,
+                            filename,
+                            prop_dict )
+                else:
+                    dialog = wb_subversion_properties_dialog.FilePropertiesDialog( self.app,
+                            self.list_panel.list_ctrl,
+                            filename,
+                            prop_dict )
                 if dialog.ShowModal() == wx.OK:
                     for present, name, value in dialog.getModifiedProperties():
                         if not present:
@@ -707,8 +732,7 @@ class SubversionListHandler(wb_list_panel.ListHandler):
             self.app.refreshFrame()
 
     def Cmd_File_Rename( self, all_rows ):
-        for row in all_rows:
-            old_filename = self.getFilename( row )
+        for old_filename in [self.getFilename( row ) for row in all_rows]:
             old_name = os.path.basename( old_filename )
 
             new_name, force = self.app.renameFile( "Rename", old_name, None )
@@ -734,29 +758,62 @@ class SubversionListHandler(wb_list_panel.ListHandler):
         self.app.refreshFrame()
 
     def Cmd_File_Revert( self, all_rows ):
-        if self.app.confirmAction( 'Revert', self.getStatusAndFilenames( all_rows ) ):
-            try:
-                for row in all_rows:
-                    filename = self.getFilename( row )
-                    self.project_info.client_fg.revert( filename )
-            except pysvn.ClientError, e:
-                self.app.log_client_error( e )
-            self.app.refreshFrame()
+        if not self.app.confirmAction( 'Revert', self.getStatusAndFilenames( all_rows ) ):
+            return
+
+        try:
+            for filename in [self.getFilename( row ) for row in all_rows]:
+                self.project_info.client_fg.revert( filename )
+        except pysvn.ClientError, e:
+            self.app.log_client_error( e )
+        self.app.refreshFrame()
 
     def Cmd_File_Resolved( self, all_rows ):
-        if self.app.confirmAction( 'Resolved', self.getStatusAndFilenames( all_rows ) ):
+        if not self.app.confirmAction( 'Resolved', self.getStatusAndFilenames( all_rows ) ):
+            return
+
+        try:
+            for filename in [self.getFilename( row ) for row in all_rows]:
+                self.project_info.client_fg.resolved( filename )
+        except pysvn.ClientError, e:
+            self.app.log_client_error( e )
+        self.app.refreshFrame()
+
+    def Cmd_File_Unlock( self, all_rows ):
+        confirmed, force = self.app.confirmForceAction( 'Unlock', self.getStatusAndFilenames( all_rows ) )
+        if not confirmed:
+            return
+
+        for filename, url in [(self.getFilename( row ), self.getUrl( row )) for row in all_rows]:
+            self.app.setProgress( 'Unlocking %(count)d', 0 )
+
+            self.app.setAction( 'Unlocking %s...' % filename )
+
+            yield self.app.backgroundProcess
+
+            ok = False
             try:
-                for row in all_rows:
-                    filename = self.getFilename( row )
-                    self.project_info.client_fg.resolved( filename )
+                if force:
+                    self.project_info.client_bg.unlock( url, force=True )
+                else:
+                    self.project_info.client_bg.unlock( filename, force=False )
+                ok = True
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
-            self.app.refreshFrame()
+
+            yield self.app.foregroundProcess
+
+            if not ok:
+                break
+
+        self.app.clearProgress()
+        self.app.setAction( 'Ready' )
+        self.app.refreshFrame()
 
     def Cmd_File_Update( self, all_rows ):
         self.app.setProgress( 'Updated %(count)d', 0 )
-        for row in all_rows:
-            filename = self.getFilename( row )
+
+        for filename in [self.getFilename( row ) for row in all_rows]:
             self.app.setAction( 'Update %s...' % filename )
 
             yield self.app.backgroundProcess
@@ -787,7 +844,6 @@ class SubversionListHandler(wb_list_panel.ListHandler):
         self.app.setAction( 'Ready' )
         self.app.refreshFrame()
 
-
 class SortList:
     def __init__( self, sort_data, project_info ):
         self.sort_data = sort_data
