@@ -28,6 +28,10 @@ import wb_subversion_utils
 
 _debug_performance = False
 
+class ErrorWrapper:
+    def __init__( self, args ):
+        self.args = args
+
 class ProjectInfo(wb_source_control_providers.ProjectInfo):
     def __init__( self, app, parent ):
         wb_source_control_providers.ProjectInfo.__init__( self, app, parent, 'subversion' )
@@ -44,7 +48,6 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         self.files_properties = {}
 
         self.tags_url = None
-        self.branches_url = None
 
     def __repr__( self ):
         return '<wb_subversion_provider.ProjectInfo url=%s, wc_path=%s>' % (self.url, self.wc_path)
@@ -76,18 +79,12 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             self.client_bg.callback_ssl_server_trust_prompt = CallFunctionOnMainThread( self.app, self.getServerTrust )
 
         self.tags_url = kws.get( 'tags_url', '' )
-        self.branches_url = kws.get( 'branches_url', '' )
 
     def getTagsUrl( self, rel_url ):
         if self.parent is not None:
             return self.parent.getTagsUrl( rel_url )
         return self.expandedLabelUrl( self.tags_url, rel_url )
 
-    def getBranchesUrl( self, rel_url ):
-        if self.parent is not None:
-            return self.parent.getBranchesUrl( rel_url )
-        return self.expandedLabelUrl( self.branches_url, rel_url )
-
     def expandedLabelUrl( self, label_url, rel_url ):
         if label_url is '':
             return ''
@@ -122,6 +119,12 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             self.app.foregroundProcess( self.app.incProgress, () )
             return
 
+        if hasattr( pysvn.wc_notify_action, 'failed_lock' ):
+            if action in [pysvn.wc_notify_action.failed_lock,
+                            pysvn.wc_notify_action.failed_unlock]:
+                self.app.log_client_error( ErrorWrapper( arg_dict['error'] ) )
+                return
+
         # see if we want to handle this action
         if wb_subversion_utils.wc_notify_action_map[ arg_dict['action'] ] is None:
             return
@@ -151,14 +154,9 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         else:
             tags_url = ''
 
-        if get_option.has( 'branches_url' ):
-            branches_url = get_option.getstr( 'branches_url' )
-        else:
-            branches_url = ''
-
         # expand any ~/ or ~user/ in the path
         wc_path = os.path.expanduser( wc_path )
-        self.init( name, url=url, wc_path=wc_path, tags_url=tags_url, branches_url=branches_url )
+        self.init( name, url=url, wc_path=wc_path, tags_url=tags_url )
 
     def writePreferences( self, set_option ):
         # save state into a preference file
@@ -167,7 +165,6 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         set_option.set( 'url', self.url )
         set_option.set( 'wc_path', self.wc_path )
         set_option.set( 'tags_url', self.tags_url )
-        set_option.set( 'branches_url', self.branches_url )
 
     def isEqual( self, pi ):
         return (self.provider_name == pi.provider_name
@@ -228,7 +225,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             self.url = entry.url
 
         t0 = time.time()
-        self.all_files_status = self.client_fg.status( self.wc_path, recurse=p.view_recursive, no_ignore=True )
+        self.all_files_status = self.client_fg.status( self.wc_path, recurse=p.view_recursive, ignore=False )
         t1 = time.time()
         if _debug_performance: print 'updateStatus: %6.3f - %-8s %s' % (t1-t0, 'status', self.wc_path)
 
