@@ -20,6 +20,7 @@ import wb_subversion_project_info
 import wb_subversion_utils
 import wb_subversion_info_dialog
 import wb_subversion_history
+import wb_subversion_properties_dialog
 
 class SubversionProject(wb_tree_panel.TreeProjectItem):
     def __init__( self, app, project_info ):
@@ -173,7 +174,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             ,('', wb_ids.id_SP_Delete, 'Delete' )
             ,('', wb_ids.id_SP_Revert, 'Revert' )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_Cleanup, 'Clear Locks' )
+            ,('', wb_ids.id_SP_Cleanup, 'Clean up' )
             ]
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_item )
@@ -196,7 +197,11 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
         yield self.app.backgroundProcess
         try:
-            self.project_info.client_bg.checkout( self.project_info.url, self.project_info.wc_path, recurse=True )
+            # lose any trailing / on the URL it stops checkout working
+            url = self.project_info.url
+            if url[-1] == '/':
+                url = url[:-1]
+            self.project_info.client_bg.checkout( url, self.project_info.wc_path, recurse=True )
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
@@ -306,15 +311,6 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                             '' ) )
 
 
-                branches_url = self.project_info.getBranchesUrl( info.url )
-                if branches_url:
-                    for ls_info in self.project_info.client_bg.ls( branches_url ):
-                        history_entries.append( (ls_info['created_rev'].number,
-                            ls_info['last_author'],
-                            ls_info['time'],
-                            'Branch ' + ls_info['name'].split('/')[-1],
-                            '' ) )
-
                 history_entries.sort()
 
                 ok = True
@@ -360,7 +356,34 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         self.app.expandSelectedTreeNode()
 
     def Cmd_Dir_Properties( self ):
-        print 'Cmd_Dir_Properties Not implemented'
+        client_fg = self.project_info.client_fg
+
+        filename = self.project_info.wc_path
+
+        try:
+            prop_list = client_fg.proplist( filename,
+                    revision=pysvn.Revision( pysvn.opt_revision_kind.working ) )
+            if len(prop_list) == 0:
+                prop_dict = {}
+            else:
+                _, prop_dict = prop_list[0]
+            dialog = wb_subversion_properties_dialog.DirPropertiesDialog( self.app,
+                    self.app.frame.tree_panel.tree_ctrl,
+                    filename,
+                    prop_dict )
+            if dialog.ShowModal() == wx.OK:
+                for present, name, value in dialog.getModifiedProperties():
+                    if not present:
+                        # delete name
+                        client_fg.propdel( name, filename )
+                    else:
+                        # add/update name value
+                        client_fg.propset( name, value, filename )
+
+        except pysvn.ClientError, e:
+            self.app.log_client_error( e )
+
+        self.app.refreshFrame()
 
     def Cmd_Dir_Rename( self ):
         old_filename = self.project_info.wc_path
